@@ -2,12 +2,16 @@
 Obsplot main class.
 """
 
+import shutil
+import os
+import signal
+from subprocess import Popen, PIPE, SubprocessError
 from IPython.display import display
 from typing import Any
 
 from .widget import ObsplotWidget
 from .jsdom import ObsplotJsdom
-from .utils import allowed_defaults
+from .utils import allowed_defaults, min_npm_version
 
 
 class Obsplot:
@@ -40,9 +44,7 @@ class Obsplot:
         if renderer == "widget":
             return ObsplotWidgetCreator(default=default, debug=debug)
         elif renderer == "jsdom":
-            if debug:
-                raise ValueError("debug mode is not available with jsdom renderer")
-            return ObsplotJsdomCreator(default=default)
+            return ObsplotJsdomCreator(default=default, debug=debug)
         else:
             raise ValueError(
                 f"""
@@ -57,7 +59,7 @@ class ObsplotCreator:
     Creator class.
     """
 
-    def __init__(self, default: dict = {}) -> None:
+    def __init__(self, default: dict = {}, debug: bool = False) -> None:
         """Generic Creator constructor
 
         Args:
@@ -69,6 +71,14 @@ class ObsplotCreator:
                     f"{k} is not allowed in default.\nAllowed values: {allowed_defaults}."  # noqa: E501
                 )
         self._default = default
+        self._debug = debug
+
+    def __repr__(self):
+        return (
+            f"<{type(self).__name__}>\n"
+            f"debug: {self._debug!r}\n"
+            f"default: {self._default!r}\n"
+        )
 
     def get_spec(self, *args, **kwargs):
         """
@@ -99,12 +109,11 @@ class ObsplotWidgetCreator(ObsplotCreator):
     """
 
     def __init__(self, default: dict = {}, debug: bool = False) -> None:
-        super().__init__(default)
-        self._debug = debug
+        super().__init__(default, debug)
 
     def __call__(self, *args, **kwargs) -> ObsplotWidget:
         """
-        Method called whent an instance is called.
+        Method called when an instance is called.
         """
         spec = self.get_spec(*args, **kwargs)
         return ObsplotWidget(spec, default=self._default, debug=self._debug)
@@ -115,12 +124,69 @@ class ObsplotJsdomCreator(ObsplotCreator):
     Jsdom renderer Creator class.
     """
 
-    def __init__(self, default: dict = {}) -> None:
-        super().__init__(default)
+    def __init__(self, default: dict = {}, debug: bool = False) -> None:
+        super().__init__(default, debug)
+        self._proc = None
+        self.start_server()
 
     def __call__(self, *args, **kwargs) -> None:
         """
-        Method called whent an instance is called.
+        Method called when an instance is called.
         """
+        if self._proc.poll() is not None:
+            raise RuntimeError(
+                "Server has ended, please recreate your plot generator object."
+            )
         spec = self.get_spec(*args, **kwargs)
-        display(ObsplotJsdom(spec, default=self._default).plot())
+        display(
+            ObsplotJsdom(
+                spec,
+                port=self._port,
+                default=self._default,
+                debug=self._debug,
+            ).plot()
+        )
+
+    def start_server(self):
+        """
+        Start http node plot generator server.
+        """
+        if self._proc is not None:
+            if self._proc.poll() is None:
+                # If proc already running, do nothing
+                return
+        # Check for node executable
+        npx = shutil.which("npx")
+        if not npx:
+            raise RuntimeError("npx executable has not been found.")
+        # Run node script with JSON spec as input
+        try:
+            p = Popen(
+                ["npx", f"pyobsplot@{min_npm_version}"],
+                stdin=None,
+                stdout=PIPE,
+                stderr=PIPE,
+                encoding="Utf8",
+                # Use shell=True if we are on Windows. Otherwise PATH
+                # is not parsed and npx is not found.
+                shell=os.name == "nt",
+                start_new_session=True,
+            )
+        except SubprocessError:
+            err = p.stderr.read()
+            raise RuntimeError(f"Can't start server: {err}")
+        # read back OS selected port from stdout
+        try:
+            port = p.stdout.readline()
+            self._port = int(port.strip())
+        except ValueError:
+            err = p.stderr.read()
+            raise ValueError(f"Server not started: {err}")
+        # store Popen process
+        self._proc = p
+
+    def close(self):
+        """
+        Stop http node plot generator server.
+        """
+        os.killpg(os.getpgid(self._proc.pid), signal.SIGTERM)
